export interface TimeToStringArgs {
    time: number;
    units?: number;
    format?: "daytime" | "string";
}
/**
 * Converts a time (in milliseconds) to a string (with the number of days/hours...).
 * The units available are: day/hour/minute/second.
 *
 * There's 2 possible display formats.
 * daytime:
 *     `dd hh:mm:ss` (where d=day, h=hour, m=minute, s=second)
 * string:
 *     `(d) days (h) hours (m) minutes (s) seconds`
 *
 * The number of `units` can limit the number of units shown in the string format (days/hours, or hours/minutes or minutes/seconds, and not days/hours/minutes for example (for a `units` with value 2)).
 *
 * Defaults:
 *     units: 2
 *     format: string
 *
 * Throws an `Error` exception if:
 * - the `time` argument isn't a number.
 */
export declare function timeToString(args: TimeToStringArgs): string;
