/**
 * Count-up or count-down timer. Can optionally update an html element.
 */
export declare class Timer {
    private is_active;
    private start_value;
    private count_down;
    private time_count;
    private interval;
    private end_value?;
    private end_callback?;
    private tick_callback?;
    private interval_f?;
    private html_element?;
    constructor(htmlElement?: HTMLElement);
    /**
     * Start counting.
     * If no endValue is given, it never stops counting.
     *
     * `startValue` and `endValue` are in milliseconds.
     *
     * `onEnd` is called when the timer ends (only if an `endValue` was provided).
     * `onTick` is called every second.
     * `countDown` if it counts up or down (default is count up).
     * `interval` time in between each tick (default is 1000 milliseconds).
     */
    start(args?: {
        startValue?: number;
        endValue?: number;
        onEnd?: () => void;
        onTick?: () => void;
        countDown?: boolean;
        interval?: number;
    }): void;
    /**
     * Resumes the timer with the same settings/values that were set before it was stopped.
     */
    resume(): void;
    /**
     * Stop counting.
     */
    stop(): void;
    /**
     * Stops and resets the count.
     */
    reset(): void;
    /**
     * Restart the timer.
     */
    restart(): void;
    /**
     * Updates the associated html element (if was given) with the current time value.
     */
    updateHtmlElement(): void;
    /**
     * Adds time to the current value in the timer. So for example, if the timer is right now at 4 seconds, and we add 1000 (1 second), it jumps to 5 seconds.
     *
     * @param time In milliseconds.
     */
    add(time: number): void;
    /**
     * Returns a string with the time passed so far.
     */
    getTimeString(): string;
    /**
     * Returns the time it has passed so far, in seconds.
     */
    getTimeSeconds(): number;
    /**
     * Returns the time it has passed so far, in milliseconds.
     */
    getTimeMilliseconds(): number;
    /**
     * Returns whether the timer is currently active or not.
     */
    isActive(): boolean;
}
